<img alt="PyPI - Version" src="https://img.shields.io/pypi/v/{package_name}">
<img alt="PyPI - Format" src="https://img.shields.io/pypi/format/{package_name}">
<img alt="PyPI - Implementation" src="https://img.shields.io/pypi/implementation/{package_name}">
<img alt="PyPI - Status" src="https://img.shields.io/pypi/status/{package_name}">
<img alt="PyPI - Downloads" src="https://img.shields.io/pypi/dd/{package_name}">
<img alt="PyPI - Downloads" src="https://img.shields.io/pypi/dw/{package_name}">
<a href="https://github.com/{owner_name}/{repo_name}" title="Go to GitHub repo"><img src="https://img.shields.io/static/v1?label={repo_name}&message={owner_name}&color=blue&logo=github"></a>
<img alt="GitHub Repo stars" src="https://img.shields.io/github/stars/{owner_name}/{repo_name}">
<a href="https://github.com/{owner_name}/{repo_name}"><img alt="forks - {owner_name}" src="https://img.shields.io/github/forks/{repo_name}/{owner_name}?style=social"></a>
<a href="https://github.com/{owner_name}/{repo_name}"><img alt="GitHub Last Commit" src="https://img.shields.io/github/last-commit/{owner_name}/{repo_name}"></a>
<a href="https://github.com/{owner_name}/{repo_name}"><img alt="GitHub Top Language" src="https://img.shields.io/github/languages/top/{owner_name}/{repo_name}"></a>
<img alt="GitHub Release" src="https://img.shields.io/github/v/release/{owner_name}/{repo_name}?color=red">
<img alt="GitHub Tag" src="https://img.shields.io/github/v/tag/{owner_name}/{repo_name}?sort=semver&color=orange">
<img alt="GitHub Actions Workflow Status" src="https://img.shields.io/github/actions/workflow/status/{owner_name}/{repo_name}/publish-to-pypi.yml">